@@ -112,7 +112,7 @@ public class JGDPanel extends JPanel implements GDContainer, MouseListener {
                     par[0]=Class.forName("java.lang.String");
                     m=c.getMethod("eval",par);
                     Object[] pars=new Object[1];
-                    pars[0]="try(.C(\"javaGDresize\",as.integer("+devNr+")),silent=TRUE)";
+                    pars[0]="try(JavaGD:::.javaGD.resize("+devNr+"),silent=TRUE)";
                     m.invoke(o, pars);
                 }
             }
